@@ -163,7 +163,7 @@ fi
 
 # Check that a few mandatory programs are installed
 missing_progs="no"
-for prog in perl tar wget cpio unzip rsync bc cmp find xargs ${DL_TOOLS} ; do
+for prog in perl tar wget cpio unzip rsync bc cmp ${DL_TOOLS} ; do
 	if ! which $prog > /dev/null ; then
 		echo "You must install '$prog' on your build machine";
 		missing_progs="yes"
@@ -177,20 +177,6 @@ for prog in perl tar wget cpio unzip rsync bc cmp find xargs ${DL_TOOLS} ; do
 			echo "  bzcat is usually part of the bzip2 package in your distribution"
 		elif test $prog = "cmp" ; then
 			echo "  cmp is usually part of the diffutils package in your distribution"
-		elif test $prog = "find" ; then
-			echo "  find is usually part of the findutils package in your distribution"
-		elif test $prog = "xargs" ; then
-			echo "  xargs is usually part of the findutils package in your distribution"
-		fi
-	fi
-
-	# we need git >= 2.0.0 for shallow clones / vendoring
-	if test $prog = "git" ; then
-		GIT_VERSION="$(git --version | sed -n 's/^git version \(.*\)/\1/p')"
-		GIT_MAJOR="$(echo "${GIT_VERSION}" | cut -d . -f 1)"
-		if [ "${GIT_MAJOR}" -lt 2 ]; then
-			echo "You have git '${GIT_VERSION}' installed. Git >= 2.0.0 is required"
-			exit 1
 		fi
 	fi
 done
@@ -213,7 +199,7 @@ if [ "${PATCH_MAJOR}" -lt 2 ] || [ "${PATCH_MAJOR}" -eq 2 -a "${PATCH_MINOR}" -l
 	exit 1;
 fi
 
-if grep -q ^BR2_NEEDS_HOST_UTF8_LOCALE=y $BR2_CONFIG ; then
+if grep ^BR2_NEEDS_HOST_UTF8_LOCALE=y $BR2_CONFIG > /dev/null; then
 	if ! which locale > /dev/null ; then
 		echo
 		echo "You need locale support on your build machine to build a toolchain supporting locales"
@@ -273,7 +259,7 @@ if grep -q ^BR2_HOSTARCH_NEEDS_IA32_COMPILER=y $BR2_CONFIG ; then
 	fi
 fi
 
-if grep -q ^BR2_NEEDS_HOST_GCC_PLUGIN_SUPPORT=y $BR2_CONFIG ; then
+if grep ^BR2_NEEDS_HOST_GCC_PLUGIN_SUPPORT=y $BR2_CONFIG ; then
 	if ! echo "#include <gcc-plugin.h>" | $HOSTCXX_NOCCACHE -I$($HOSTCXX_NOCCACHE -print-file-name=plugin)/include -x c++ -c - -o /dev/null ; then
 		echo
 		echo "Your Buildroot configuration needs a host compiler capable of building gcc plugins."
@@ -285,14 +271,8 @@ fi
 
 # Check that the Perl installation is complete enough for Buildroot.
 required_perl_modules="Data::Dumper" # Needed to build host-autoconf
-required_perl_modules="$required_perl_modules English" # Used by host-libxml-parser-perl
 required_perl_modules="$required_perl_modules ExtUtils::MakeMaker" # Used by host-libxml-parser-perl
 required_perl_modules="$required_perl_modules Thread::Queue" # Used by host-automake
-required_perl_modules="$required_perl_modules FindBin" # Used by (host-)libopenssl
-
-if grep -q ^BR2_PACKAGE_MOSH=y $BR2_CONFIG ; then
-    required_perl_modules="$required_perl_modules diagnostics"
-fi
 
 if grep -q ^BR2_PACKAGE_MPV=y $BR2_CONFIG ; then
     required_perl_modules="$required_perl_modules Math::BigInt"
@@ -310,13 +290,6 @@ fi
 # This variable will keep the modules that are missing in your system.
 missing_perl_modules=""
 
-if grep -q ^BR2_PACKAGE_LIBXCRYPT=y $BR2_CONFIG ; then
-	# open cannot be used with require
-	if ! perl -e "use open ':std'" > /dev/null 2>&1 ; then
-		missing_perl_modules="$missing_perl_modules open"
-	fi
-fi
-
 for pm in $required_perl_modules ; do
 	if ! perl  -e "require $pm" > /dev/null 2>&1 ; then
 		missing_perl_modules="$missing_perl_modules $pm"
